<h1 align="center">infoml</h1>

<p align="center">
<a href="https://github.com/psf/black/blob/main/LICENSE">
    <img alt="License: MIT" src="https://img.shields.io/github/license/Kabilan108/infoml">
</a>
<a href="https://github.com/psf/black">
    <img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">
</a>
<a href="https://codecov.io/gh/Kabilan108/infoml" >
    <img src="https://codecov.io/gh/Kabilan108/infoml/branch/main/graph/badge.svg?token=38Y14PAAQQ"/>
</a>
<a href="https://github.com/Kabilan108/infoml/actions/workflows/CI-CD.yml">
    <img alt="Test Status" src="https://github.com/Kabilan108/infoml/actions/workflows/CI-CD.yml/badge.svg?branch=main">
</a>
<a href="https://wakatime.com/badge/user/6a085912-85f1-47f5-acc7-c7f5ac1110ab/project/51ef67da-2e82-431e-9dc9-9bdd6d1c3d48">
    <img
    src="https://wakatime.com/badge/user/6a085912-85f1-47f5-acc7-c7f5ac1110ab/project/51ef67da-2e82-431e-9dc9-9bdd6d1c3d48.svg"
    alt="wakatime">
</a>
</p>

Python package for bioinformatics analysis and machine learning.

## Installation

```bash
pip install infoml
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note
that this project is released with a Code of Conduct. By contributing to this
project, you agree to abide by its terms.

## License

`infoml` was created by Tony Kabilan Okeke. It is licensed under the terms of
the MIT license.

## Credits

`infoml` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/)
and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
